Unity 7.6 ya fue liberado y estas son sus novedades

Hace poco los desarrolladores del proyecto Ubuntu Unity, que desarrolla una edición no oficial de Ubuntu Linux con el escritorio Unity, anunciaron la formación de una versión estable del shell de usuario Unity 7.6.

El skin de Unity 7 se basa en la biblioteca GTK y está optimizado para un uso eficiente del espacio vertical en portátiles de pantalla panorámica. La última versión importante de Unity 7 se publicó en mayo de 2016, después de lo cual solo se agregaron correcciones de errores a la rama y un grupo de entusiastas llevó a cabo el soporte.

En Ubuntu 16.10 y 17.04, además de Unity 7, se incluyó el shell Unity 8, traducido a la biblioteca Qt5 y al servidor de visualización Mir. Canonical planeó originalmente reemplazar el shell de Unity 7, que utiliza las tecnologías GTK y GNOME, con Unity 8, pero los planes cambiaron y Ubuntu 17.10 volvió al GNOME normal con Ubuntu Dock y el desarrollo de Unity 8 se suspendió.

El desarrollo de Unity 8 lo recogió el proyecto UBports, que desarrolla su propio fork bajo el nombre de Lomiri. El shell de Unity 7 se abandonó durante algún tiempo, hasta que se creó una nueva edición no oficial de Ubuntu, Ubuntu Unity, sobre esta base en 2020. La distribución Ubuntu Unity está siendo desarrollada por Rudra Saraswat, un niño de 12 años de la India.

Principales novedades de Unity 7.6

Unity 7.6 será el primer lanzamiento importante de Unity en 6 años (el último lanzamiento fue en mayo de 2016). Hemos reiniciado el desarrollo activo de Unity7 y lanzaremos nuevas versiones con más funciones regularmente. Se lanzó una actualización para los usuarios de Ubuntu Unity 22.04, así que ejecute sudo apt update && sudo apt upgradepara actualizar a Unity 7.6, o puede esperar a que el actualizador de software busque actualizaciones.

Se ha modernizado la apariencia del menú de la aplicación (Dash) y la interfaz emergente de búsqueda rápida HUD (Heads-Up Display).

De los cambios más destacables se destaca que se pasó a una apariencia más plana, pero se retuvieron los efectos de desenfoque, ademas de que se ha rediseñado el diseño de los elementos del menú de la barra lateral y la información sobre herramientas.

Tambien se destaca el trabajo mejorado en modo de gráficos bajos, cuando el controlador vesa está habilitado si no se pueden usar controladores de video nativos, asi como tambien que se ha mejorado el rendimiento del panel de control.

Ademas de ello tambien se destaca un consumo de memoria ligeramente reducido. En cuanto a la distribución Ubuntu Unity 22.04, su entorno basado en Unity 7 consume entre 700 y 800 MB.

De los demás cambios que se destacan:

  • Se corrigieron problemas con la aplicación incorrecta y la información de calificación que se muestra al obtener una vista previa en Dash.
  • Se solucionó el problema de mostrar el botón de carrito vacío en el panel (el controlador basado en el administrador de archivos Nautilus se movió para usar Nemo).
  • El desarrollo se trasladó a GitLab.
  • Se han reelaborado las pruebas de montaje.
  • En comparación con la versión de prueba de mayo de Unity 7.6, se observan los siguientes cambios en la versión final:
  • Representación mejorada de esquinas más redondeadas en el panel Dash.
  • El tablero se reemplazó con la aplicación unity-control-center.
  • Se agregó soporte para colores de énfasis en Unity y unity-control-center.
  • La lista de máscaras se ha actualizado en unity-control-center.

Finalmente si estás interesado en poder conocer más al respecto, puedes consultar los detalles en el siguiente enlace.

Descargar y probar Unity 7.6

Para aquellos que están interesados en poder probar esta versión estable pueden hacerlo de dos formas diferentes, la primera de ellas es para quienes estén utilizando Ubuntu Unity.

Para obtener la nueva versión solo basta con que abran una terminal y sobre ella tecleen los siguientes comandos:

sudo apt update && sudo apt full-upgrade

Ahora para quienes son usuarios de cualquier otro derivado de Ubuntu, pueden instalar los paquetes necesarios añadiendo el siguiente repositorio.

Para ello solo deben abrir una terminal y en ella vamos a teclear los siguientes comandos:

sudo wget https://repo.unityx.org/unityx.key

sudo apt-key add unityx.key echo 'deb https://repo.unityx.org/main stable main' | sudo tee /etc/apt/sources.list.d/unity-x.list

sudo apt-get update && sudo apt-get install -y unity

from Linux Adictos https://ift.tt/fIsex6V
via IFTTT

Para GTK5 se esta considerando finalizar el soporte para X11

Matthias Clasen, líder del equipo de escritorio de Fedora, miembro del equipo de lanzamiento de GNOME y uno de los desarrolladores activos de GTK (contribuyó con el 36,8% de los cambios en GTK 4), comenzó a discutir la posibilidad de desaprobar el protocolo X11 en la próxima rama importante de GTK5 y dejando GTK ejecutándose en Linux solo usando el protocolo Wayland.

Para quienes desconocen de Wayland, deben saber que este es un protocolo para la interacción de un servidor compuesto y las aplicaciones que trabajan con él. Los clientes hacen su propia representación de sus ventanas en un búfer separado, pasando información sobre las actualizaciones al servidor compuesto, que combina los contenidos de los búferes de aplicaciones individuales para formar el resultado final, teniendo en cuenta los posibles matices, como la superposición de ventanas y la transparencia.

En otras palabras, el servidor compuesto no proporciona una API para renderizar elementos individuales, sino que solo opera en ventanas ya formadas, lo que le permite deshacerse del doble almacenamiento en búfer cuando usa bibliotecas de alto nivel como GTK y Qt, que se hacen cargo del trabajo de ordenar el contenido de las ventanas.

Wayland resuelve muchos problemas de seguridad de X11 porque, a diferencia de este último, aísla la entrada y la salida para cada ventana, no permite que el cliente acceda al contenido de las ventanas de otros clientes y tampoco permite la interceptación de eventos de entrada asociados con otras ventanas. Actualmente, ya se ha implementado el soporte para el trabajo directo con Wayland para las bibliotecas GTK, Qt, SDL (desde la versión 2.0.2), Clutter y EFL (Enlightenment Foundation Library). A partir de Qt 5.4, el módulo QtWayland se incluye con la implementación de componentes para ejecutar aplicaciones Qt en el entorno del servidor compuesto Weston desarrollado por el proyecto Wayland.

Sobre la nota propuesta de desaprobación de X11 establece que «X11 no está mejorando y Wayland ya está disponible universalmente». Explica además que el backend X11 GTK y el código basado en Xlib se están estancando y experimentan problemas con los mantenedores.

Se afirma que para que sobreviva la compatibilidad con X11, alguien tiene que escribir y mantener el código relacionado con X11, pero no hay entusiastas, y los desarrolladores actuales de GTK se centran principalmente en la compatibilidad con Wayland. Los desarrolladores de sistemas interesados ​​en trabajar en entornos basados ​​en el protocolo X11 pueden tomar el mantenimiento en sus propias manos y extender su soporte en GTK, pero dada la actividad actual, el escenario será que habrá quienes quieran tomar el mantenimiento del backend X11. en sus propias manos se considera improbable.

Actualmente, GTK ya está posicionando a Wayland como la principal plataforma de desarrollo de funcionalidades y APIs. Debido a la falta de actividad en el desarrollo del protocolo X11, mientras deja su soporte en GTK, el backend X11 generará una acumulación cada vez mayor en términos de nuevas funcionalidades disponibles para los desarrolladores, o se convertirá en un obstáculo para la implementación de nuevas características en GTK.

Cabe mencionar que de acuerdo con las estadísticas del servicio Firefox Telemetry, que analiza los datos recibidos como resultado del envío de telemetría y de los usuarios que acceden a los servidores de Mozilla, la proporción de usuarios de Firefox en Linux que trabajan en entornos basados ​​en el protocolo Wayland no supera el 10 %.

El 90% de los usuarios de Firefox en Linux continúan usando el protocolo X11. Un entorno Wayland puro es utilizado por alrededor del 5-7% de los usuarios de Linux, y XWayland por alrededor del 2%.

La información utilizada para el informe cubre aproximadamente el 1 % de la telemetría recibida de los usuarios de Firefox en Linux. El resultado puede verse muy afectado al deshabilitar la telemetría en paquetes con Firefox que se ofrecen en algunas distribuciones de Linux (la telemetría está habilitada en Fedora).

Por su parte KDE planea en 2022 llevar la sesión de escritorio Plasma basada en el protocolo Wayland a un estado adecuado para el uso diario de una proporción significativa de usuarios. La compatibilidad significativamente mejorada para Wayland en las versiones KDE Plasma 5.24 y 5.25, incluida la compatibilidad con profundidades de color superiores a 8 bits por canal, «arrendamiento DRM» para auriculares VR, compatibilidad para tomar capturas de pantalla y minimizar todas las ventanas.

from Linux Adictos https://ift.tt/1iyzuBA
via IFTTT

Herramientas gráficas de automatización. Linux y pecados capitales parte 5

Captura de pantalla de Autokey

Con el programa de automatización Autokey podemos evitarnos ingresar textos repetitivos como direcciones o números de tarjetas de crédito o crear scripts que automaticen tareas.

Esta serie de artículos tiene dos intenciones: la principal es la de dar a conocer algunos de los títulos de la extensa colección de software libre y de código abierto. La segunda que nos sirve de excusa es como ayudar a los peores pecadores a ganarse su lugar en el Infierno.

Llevo varios artículos indicándole a los perezosos como endilgarle las tareas que no quieren hacer al ordenador y, a decir verdad, lograr eso con las herramientas que venimos comentando requiere, al menos al principio, de bastante trabajo. Es por eso, que vamos a probar suerte con algunas herramientas gráficas de automatización.

Herramientas gráficas de automatización

Hasta el momento comentamos herramientas que ejecutaban comandos en momentos establecidos previamente. Ahora vamos a hablar de otras que podemos utilizar en cualquier momento ahorrándonos trabajos como escribir largos textos o buscar opciones de menú en aplicaciones.

Autokey

Esta herramienta que viene en versiones para las librerías Qt y GTK nos permite crear accesos directos de teclado para las funciones que usamos más seguido de nuestros programas preferidos. También nos da la posibilidad de asociar largos fragmentos de texto a cadenas cortas.

Instalación

Autokey está disponible en dos versiones:

  • autokey-gtk: Recomendada para escritorios GNOME, Mate, Cinnamon y XFCE.
  • autokey-qt: Ideal para KDE y LXQt.

Podemos buscarlas e instalarlas en el gestor de paquetes de las principales distribuciones.

Utilización

Podemos utilizar AutoKey en dos formas:

  • Para crear accesos directos o palabras claves que refieran a textos más largos.
  • Ejecución de tareas complejas mediante scripts en python.

funciona con dos tipos diferentes de entradas. Podemos usar texto sin formato simple, que Autokey identifica como frases, para crear accesos directos y fragmentos de texto que se expandirán a textos más extensos. También podemos usarlo para automatizar tareas complicadas escribiendo scripts de Python simples.

Se incluyen algunas muestras para facilitar la comprensión de cada uno. Por ejemplo, si pulsamos en Adresses dentro de la carpeta My phrases podemos hacer que, si se cumplen determinadas condiciones, nuestra dirección aparezca al escribir la abreviatura adr.

Creando nuestras propias frases
  • Hacemos clic en New.
  • Seleccionamos Phrase en el menú desplegable.
  • Elegimos un nombre para la nueva entrada.
  • En la ventana superior izquierda escribimos el texto extendido.
  • Pulsamos set en el parámetro Abbreviation.
  • Pulsamos en el signo + en la esquina inferior izquierda del programa.
  • Escribimos la abreviatura y pulsamos Enter.
  • Pulsamos en OK

Las opciones adicionales para las abreviaturas son:

  • Remover la abreviatura cuando se reemplaza por el texto largo.
  • Hacer que coincidan las mayúsculas y minúsculas.
  • Ignorar coincidencias de mayúsculas y minúsculas.
  • Ignorar si la abreviatura es parte de una palabra.

En lugar de usar abreviaturas, podemos asignar atajos de teclado a fragmentos de texto largo utilizando el siguiente procedimiento.

  • Completamos el texto en la parte superior.
  • En Hotkey pulsamos en Set.
  • Elegimos una tecla base entre Control, Alt, Shift, Hyper, Super o Meta.
  • Pulsamos en Record a key combination.
  • Pulsamos la o las teclas que completarán la combinación.
  • Finalizamos pulsando en Aceptar.

Si solo queremos que Autokey complete el texto en una sola aplicación hacemos lo siguiente:

  • Pulsamos Set en Windows Filter.
  • Abrimos la aplicación deseada.
  • Pulsamos en Detect Windows Properties.
  • Pulsamos en la ventana de la aplicación.
  • Pulsamos en Aceptar.

En todos los casos, cuando terminamos la configuración la guardamos con Save desde el menú File

Script de muestra de Autokey

Autokey contiene algunas muestras de lo que puede hacer esta potente herramienta de automatización.

Se habrán dado cuenta de que la mayoría de los comandos están en inglés. Esto es así al menos en la versión Autokey-QT que instala Ubuntu Studio 22.04

En el próximo artículo veremos como automatizar tareas usando scripts. Sin embargo, hay otra forma de automatizar menos complicada. Simplemente copiamos las combinaciones de teclas de los atajos de teclado de nuestras aplicaciones preferidas más instrucciones adicionales.

from Linux Adictos https://ift.tt/XZoaw7f
via IFTTT

La configuración de anacrontab. Linux y pecados capitales cuarta parte

Página del manual de anacron

Anacron permite ejecutar programas aunque la fecha indicada se haya pasado.

Estamos haciendo una lista de software y herramientas para Linux utilizado como guía la lista de los siete pecados capitales. Al igual que en los artículos anteriores usamos a la pereza como excusa para hablar de herramientas de automatización en Linux. Una de ellas en anacron.  En este artículo veremos cómo es la configuración de anacrontab. anacrontab es la que le indica a anacron qué es lo que debe hacer y cuándo hacerlo.

En anacron la fecha de las tareas se fija en días y, en caso de que el ordenador no esté funcionando al momento de ejecutar una tarea, esta se pone en marcha cuando este se pone en marcha.

La configuración de anacrontab

En principio anacron busca la lista de tareas a ejecutar en el directorio /etc/anacrontab. Las tareas deben escribirse en el siguiente formato:

período retraso identificador del trabajo comando donde:

  • período: Frecuencia con la que debe realizarse el trabajo. Puede expresarse en días (su abreviatura en inglés) lapso ( @daily, @weekly, o @monthly para día, semana o mes) o con números (1 para día, 7 para semana, 30 para mes y cualquier número para un período arbitrario de días.
  • retraso: La cantidad de tiempo a esperar antes de comenzar el trabajo. Por ejemplo 360 para ejecutar una tarea a las 6 de la mañana.
  • identificador del trabajo: Nombre asignado al trabajo para distinguirlo de los otros en los informes de errores y resultados
  • .

  • comando: Es la instrucción que debe ejecutar anacron en el momento señalado.

Como nuestra intención es usar anacron para tareas que no tienen que ver con la administración del sistema, vamos a replicar los directorios usados por cron en nuestra carpeta de usuario local. Lo hacemos con

mkdir -p ~/.local/etc/anacrontab: ~/.local/etc/cron.daily ~/.local/etc/cron.weekly ~/.local/etc/cron.daily  ~/.var/spool/anacron

Con esto creamos los directorios para guardar los distintos scripts diarios, semanales y mensuales, así como el lugar donde se va a guardar el informe de la última ejecución de anacron.

Para terminar, le indicamos a anacron que use nuestras carpetas de usuario local en lugar de las del sistema.

anacron -fn -t ~/.local/etc/anacrontab -S ~/.var/spool/anacron

Ahora vamos a editar un archivo de configuración. Lo hacemos desde la terminal con:

nano ~/.local/etc/anacrontab:

En el documento que se abre agregamos estas líneas:

SHELL=/bin/sh
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin

Estas líneas cumplen las mismas funciones que ya explicamos para crontab. Indicar que debe usar Bash como intérprete de comandos y en que directorios encontrar los ejecutables. Guardamos el documento con May + 0 y lo cerramos con May +  X.

El nombre y la ubicación de las carpetas cron que creamos es una elección arbitraria. Yo opté por mantener los que se usan por defecto para no confundir a los lectores que requieran de información adicional de otras fuentes. Mientras en acrontab se indique la ruta al script se puede usar la carpeta y ruta de almacenamiento que se prefiera. Lo mismo vale para el identificador del trabajo.

Hay otras dos variables que podemos configurar:

  • START_HOURS_RANGE
  • : establece el rango de tiempo en el que se iniciarán los trabajos (es decir, ejecutar trabajos solo durante las siguientes horas).

  • RANDOM_DELAY
  • : esto define el retraso aleatorio máximo agregado al retraso definido por el usuario de un trabajo (por defecto es 45).

¿Cuál es la diferencia entre cron y anacron?

cron es lo que en los sistemas y derivados se conoce como un daemon es decir un programa que se ejecuta en segundo plano y sin intervención del usuario. Está pensado para servidores, es decir equipos que funcionan en forma casi permanente sin necesidad de que nadie esté prestándole atención, pero requiere frecuentes tareas de mantenimiento.

anacron  es un programa normal más apto para computadoras de escritorio que no están continuamente encendidas. Es por eso que, a diferencia de cron, donde la menor unidad de tiempo es el minuto, se trabaja con una frecuencia mínima de un día.

Por el mismo motivo, cron no incluye alternativas para el caso de que el equipo no esté encendid
o mientras que anacron repasa las tareas pendientes al iniciar sesión.  Cuando encuentra un trabajo no iniciado en el momento establecido, ejecutará el comando especificado en el campo de comando después de esperar el número de minutos indicado en el campo de retraso. Luego registrará la fecha en un archivo de marca de tiempo.

from Linux Adictos https://ift.tt/heKAbC4
via IFTTT

Sobre cron y anacron para perezosos. Linux y pecados capitales tercera parte

Archivo de crontab vació

Este archivo de crontab se usa para indicarle a cron las instrucciones que debe ejecutar.

En la tercera parte de esta serie de artículos en la que estamos usando a los siete pecados capitales como excusa para conocer herramientas y programas para Linux, comentaremos más sobre la configuración de cron y hablaremos de una alternativa

cron es un programa que funciona en forma autónoma para ejecutar tareas de mantenimiento del sistema en forma periódica. Las tareas están especificadas en un archivo de texto conocido como crontab.

Sobre cron y anacron

En los artículos anteriores comentamos la estructura de las instrucciones que hay que darle a cron. Ahora veremos una forma fácil de redactar el archivo crontab.

El comando crontab –e nos genera un archivo crontab casi en blanco. Solo hay unas líneas precedidas del signo del numeral (#). Este signo indica que son comentarios y no deben intentar ejecutarse. Podemos borrarlos o dejarlos.

Deberíamos comenzar agregando estas líneas:

SHELL=/bin/bash: Especifica que el shell que se debe utilizar para ejecutar los comandos es Bash. Un shell es un intérprete de comandos que permite que el usuario acceda a recursos del sistema.

MAILTO=una_dirección_de_mail: En las distribuciones para servidor es común que se especifique una dirección de correo electrónico para que los administradores reciban informes de errores. Por eso es la opción que cron utiliza por defecto para enviarlos. En los equipos de escritorio esa dirección no está configurada por lo que podemos hacerlo con esta variable.

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin: Esto nos evita tener que especificar la ruta al ejecutable de cada comando.

anacron

Cron es la más conocida de las herramientas de automatización, pero tiene el inconveniente que, si el ordenador se apaga o está suspendido, la tarea no se realiza hasta que se vuelve a la fecha preestablecida. Anacron. por el contrario, se ocupa de que al reanudar la sesión se pongan en ejecución las tareas que quedaron pendientes. El programa averigua cuándo fue la última vez que se ejecutó una instrucción y la frecuencia con que se le indicó que debería realizarse. La lista de trabajos pendientes se registra en un archivo de texto llamado en este caso anacrontab. A diferencia de cron y crontab la fecha se establece fijando un día, un retraso en minutos, un identificador de trabajo y el comando a ejecutar.

Para cada trabajo, Anacron verifica si este trabajo se ha ejecutado en los últimos n días, donde n es el período especificado para ese trabajo. Si no, Anacron ejecuta el comando de shell del trabajo, después de esperar el número de minutos especificado como el parámetro de retraso.

Después de que finaliza el comando, Anacron registra la fecha en un archivo de marca de tiempo especial para ese trabajo, para que pueda saber cuándo ejecutarlo nuevamente. Solo se usa la fecha para los cálculos de tiempo. No se utiliza la hora.

Podemos encontrar anacron bajo este nombre o como parte de otro paquete denominado cronie en los repositorios de las principales distribuciones Linux.

Parámetros de Anacron

-f: Ejecuta la tarea sin importar si es la fecha indicada.

-u: Cambia la fecha de los trabajos a la actual, pero no los ejecuta.

-s: Establece que solo se comenzará una tarea cuando se termine la anterior.

-n: Ejecuta el trabajo sin importar que sea la fecha. Activa el parámetro -s.

-d: No se ejecuta en segundo plano y los errores se genera como un mensaje de error estándar. El resultado de los trabajos se envía por mail. En caso de tratarse de un sistema de escritorio la dirección de mail se configura como indicamos más arriba.

-q: Evita que se generen mensajes de error estándar. Se usa junto con –d.

-t: En caso de que se quiera usar una lista de tareas diferente a la que se crea por defecto, este parámetro le indica a anacron cuál debe usar.

-T: Testea la lista de tareas para ver si está correctamente configurada. En caso de que no lo esté genera un mensaje de error.

-S Almacena marcas de tiempo en un directorio especificado para ser utilizadas por anacron.

En el próximo artículo veremos como configurar correctamente anacrontab

from Linux Adictos https://ift.tt/ysnfZ7C
via IFTTT

El uso de Cron para perezosos. Linux y pecados capitales segunda parte

tigre durmiendo

Si te da pereza hacer tareas repetitivas en tu ordenador, Cron las hace por ti.

Este es el segundo artículo de una serie en la que utilizamos la lista de lo que la Iglesia Católica denomina “pecados capitales” como excusa para conocer más sobre comandos y programas del mundo Linux. En este caso continuamos hablando sobre el uso de Cron que será de gran utilidad para quienes cultivan la pereza.
Dado que estamos viviendo una época de gente de ofensa fácil permítanme aclarar, antes de entrar en materia, que no es mi intención burlarme de las creencias religiosas de nadie. En todo caso es una auto burla. Pasé gran parte del año ochenta estudiando catecismo para luego de haber tomado la Primera Comunión no volver a pisar una iglesia salvo que algún acontecimiento familiar lo requiriera. Tengo que recuperar ese tiempo de alguna manera.

Para qué sirven Cron y Crontab

Habíamos dicho que Cron es un demonio, es decir un programa que se ejecuta en segundo plano sin que el usuario tenga intervención. Buscando información adicional para este artículo descubrí que lo de traducir daemon (La forma en que los sistemas Unix y derivados denominan a este tipo de programas) como demonio es un error muy extendido, pero no voy a corregirlo. Estamos hablando de pecados, tiene que haber por lo menos un demonio.

La función de Cron es ejecutar, en un momento especificado previamente, una determinada tarea. La mayoría de las veces es por necesidades del sistema, aunque los usuarios podemos indicarle otras a partir de la edición de un archivo de texto conocido como crontab.

En el post anterior habíamos dicho que los comandos para crear crontab son:

crontab –e para el usuario por defecto

O

crontab –u nombre_de_usuario para cualquiera de los otros.

Crontab es un archivo de texto que le brinda a Cron las instrucciones sobre qué debe hacer y cuando hacerlo.

Acerca del uso de Cron mediante crontab

Para crear nuestro crontab debemos tener en cuenta lo siguiente:

  • Se utiliza una línea para cada tarea.
  • Se debe indicar la fecha y hora de ejecución de la tarea. En caso de que se trate de una tarea que requiera periodicidad. Por ejemplo, todos los miércoles a las 5 de la mañana, el resto de los parámetros se reemplazan por asteriscos (*).
  • En caso de que se quiera asignar más de un valor para un determinado parámetro cada valor debe separarse por una coma.
  • Los parámetros se separan con un espacio.
  • Se debe conocer el directorio donde está el lanzador del comando

Por ejemplo, si queremos que el ordenador de nuestros hijos se apague todos los días a las 20, la instrucción sería.

0 20 * * * /sbin/shutdown

En caso de que busquemos que el apagado sea solo los domingos cambiamos la instrucción a

0 20 * * 0 /sbin/shutdown

Existen algunos atajos que nos ahorran tener que escribir todos los parámetros. Ellos son:

  • @hourly: Ejecuta un comando a la hora en punto. 
  • @daily: Ejecuta el comando al comienzo de cada día.
  • @weekly: Ejecuta el comando al comienzo del primer día de la semana.
  • @monthly: Ejecuta el comando al comenzar el primer día de cada mes.
  • @yearly: Ejecuta el comando en el primer minuto del año.

Algunos ejemplos del uso de este comando son:

@daily /bin/sh /ruta_al_script/nombre_del_script.sh ejecuta un script en Bash.

@hourly /bin/python3 /ruta_al_script/nombre_del_script.py ejecuta un script en python cada hora.

En todos los casos los scripts deberán tener permisos de ejecución.

En los ejemplos que vimos se indica no solo el comando sino también la ruta donde se encuentra el ejecutable. Vamos a trabajar con estos directorios:

  • /bin: Que contiene todas las aplicaciones necesarias para el funcionamiento del sistema.
  • /sbin: Aquí están las aplicaciones que el usuario raíz necesita para manejar el sistema.
  • /home: Donde se almacenan las aplicaciones de cada usuario.
  • /usr: Aquí se guardan aplicaciones y archivos instalados por los usuarios. Incluyen archivos con los nombres y funciones mencionados en esta lista.

En el próximo artículo veremos cómo mejorar la redacción de crontab y algunas otras herramientas de automatización disponibles para Linux.

from Linux Adictos https://ift.tt/rT3wLQn
via IFTTT

El uso de Cron para perezosos. Linux y pecados capitales segunda parte

tigre durmiendo

Si te da pereza hacer tareas repetitivas en tu ordenador, Cron las hace por ti.

Este es el segundo artículo de una serie en la que utilizamos la lista de lo que la Iglesia Católica denomina “pecados capitales” como excusa para conocer más sobre comandos y programas del mundo Linux. En este caso continuamos hablando sobre el uso de Cron que será de gran utilidad para quienes cultivan la pereza.
Dado que estamos viviendo una época de gente de ofensa fácil permítanme aclarar, antes de entrar en materia, que no es mi intención burlarme de las creencias religiosas de nadie. En todo caso es una auto burla. Pasé gran parte del año ochenta estudiando catecismo para luego de haber tomado la Primera Comunión no volver a pisar una iglesia salvo que algún acontecimiento familiar lo requiriera. Tengo que recuperar ese tiempo de alguna manera.

Para qué sirven Cron y Crontab

Habíamos dicho que Cron es un demonio, es decir un programa que se ejecuta en segundo plano sin que el usuario tenga intervención. Buscando información adicional para este artículo descubrí que lo de traducir daemon (La forma en que los sistemas Unix y derivados denominan a este tipo de programas) como demonio es un error muy extendido, pero no voy a corregirlo. Estamos hablando de pecados, tiene que haber por lo menos un demonio.

La función de Cron es ejecutar, en un momento especificado previamente, una determinada tarea. La mayoría de las veces es por necesidades del sistema, aunque los usuarios podemos indicarle otras a partir de la edición de un archivo de texto conocido como crontab.

En el post anterior habíamos dicho que los comandos para crear crontab son:

crontab –e para el usuario por defecto

O

crontab –u nombre_de_usuario para cualquiera de los otros.

Crontab es un archivo de texto que le brinda a Cron las instrucciones sobre qué debe hacer y cuando hacerlo.

Acerca del uso de Cron mediante crontab

Para crear nuestro crontab debemos tener en cuenta lo siguiente:

  • Se utiliza una línea para cada tarea.
  • Se debe indicar la fecha y hora de ejecución de la tarea. En caso de que se trate de una tarea que requiera periodicidad. Por ejemplo, todos los miércoles a las 5 de la mañana, el resto de los parámetros se reemplazan por asteriscos (*).
  • En caso de que se quiera asignar más de un valor para un determinado parámetro cada valor debe separarse por una coma.
  • Los parámetros se separan con un espacio.
  • Se debe conocer el directorio donde está el lanzador del comando

Por ejemplo, si queremos que el ordenador de nuestros hijos se apague todos los días a las 20, la instrucción sería.

0 20 * * * /sbin/shutdown

En caso de que busquemos que el apagado sea solo los domingos cambiamos la instrucción a

0 20 * * 0 /sbin/shutdown

Existen algunos atajos que nos ahorran tener que escribir todos los parámetros. Ellos son:

  • @hourly: Ejecuta un comando a la hora en punto. 
  • @daily: Ejecuta el comando al comienzo de cada día.
  • @weekly: Ejecuta el comando al comienzo del primer día de la semana.
  • @monthly: Ejecuta el comando al comenzar el primer día de cada mes.
  • @yearly: Ejecuta el comando en el primer minuto del año.

Algunos ejemplos del uso de este comando son:

@daily /bin/sh /ruta_al_script/nombre_del_script.sh ejecuta un script en Bash.

@hourly /bin/python3 /ruta_al_script/nombre_del_script.py ejecuta un script en python cada hora.

En todos los casos los scripts deberán tener permisos de ejecución.

En los ejemplos que vimos se indica no solo el comando sino también la ruta donde se encuentra el ejecutable. Vamos a trabajar con estos directorios:

  • /bin: Que contiene todas las aplicaciones necesarias para el funcionamiento del sistema.
  • /sbin: Aquí están las aplicaciones que el usuario raíz necesita para manejar el sistema.
  • /home: Donde se almacenan las aplicaciones de cada usuario.
  • /usr: Aquí se guardan aplicaciones y archivos instalados por los usuarios. Incluyen archivos con los nombres y funciones mencionados en esta lista.

En el próximo artículo veremos cómo mejorar la redacción de crontab y algunas otras herramientas de automatización disponibles para Linux.

from Linux Adictos https://ift.tt/rT3wLQn
via IFTTT

WINE 7.12 soporta temas de aplicaciones Qt5 y vuelve a quedarse por debajo de las 300 correcciones

WINE 7.12

Como cada dos viernes en esta fase del desarrollo, WineHQ anunció en la noche de ayer 1 de julio la disponibilidad de WINE 7.12. Como hace dos semanas, estamos ante una actualización que no aporta demasiado, ni en cuanto a número de correcciones ni en cuanto a funciones destacadas. Hace ahora casi un mes al menos actualizaron el motor Mono, pero en estas dos últimas versiones de desarrollo, bueno, diremos que están siguiendo evoluciones naturales, pero tímidas.

En cuanto a lo introducido, han corregido 13 bugs, pero mirando más abajo vemos que han añadido un total de 266 cambios. La media está entre los 200 y los 400, pero yo diría que suele estar por encima de los 300 cambios. Todo lo que esté por debajo se puede considerar una actualización «floja», y eso es lo que hemos tenido esta semana. Lo que tenéis a continuación es lo que WineHQ ha considerado digno como para ser destacado de entre el resto de novedades de WINE 7.12.

Lo más destacado de WINE 7.12

Se ha destacado el soporte de temas para aplicaciones Qt5, que el vkd3d incluido ha subido a la v1.4, que se ha mejorado el soporte de efectos en Direct2D y el soporte para QWORD en las herramientas de registro, terminando la lista el habitual «varias correcciones de errores». Nada realmente destacado, pero se sigue avanzando para mejorar el soporte al ejecutar aplicaciones de Windows en otras plataformas.

WINE 7.12 está disponible desde este enlace, y por segunda semana consecutiva no vemos ese segundo enlace que solían facilitar, pero que no funcionaba. En la página de descargas hay información sobre cómo instalar esta y otras versiones en sistemas operativos como Debian y Ubuntu, pero también se puede instalar en Android y macOS.

La próxima versión será un WINE 7.13 que llegará el 15 de julio. No sabemos cuántos cambios introducirán dentro de dos semanas, pero sí deberían ser un par de cientos o más.

from Linux Adictos https://ift.tt/5ymOtc7
via IFTTT

Linux Mint 21 no usará systemd-oom, y ya está casi listo para la beta

Linux Mint 21 en obras

El Ubuntu con sabor a menta tiene una base de usuarios relativamente importante, y la tiene por algo. Canonical toma sus decisiones, y no siempre son del gusto de todos ni las más acertadas, y Clement Lefebvre y compañía van a lo suyo, a veces siguiendo el camino que marca Canonical y en ocasiones saliéndose y tomando el suyo propio. Eso es algo que parece que harán en Linux Mint 21, no adoptando algo que por el momento está provocando dolores de cabeza a los usuarios de Ubuntu.

Ubuntu 22.04 activó por defecto systemd-oomd, algo que pretendía mejorar la gestión del uso de memoria RAM, pero que está haciendo cosas que no se le piden, como cerrar aplicaciones que se están usando cuando le parece. Lefebvre no explica si los problemas que le han transmitido ha sido en Linux Mint o se refiere a los de los usuarios de Ubuntu, pero ha decidido no añadir systemd-oomd en Linux Mint 21.

La beta de Linux Mint 21 llegará en días

Con la beta ya a la vuelta de la esquina, Lefebvre ha mencionado más novedades de las habituales en una nota mensual, como:

  • El cifrado del directorio personal sigue estando disponible en el instalador.
  • Se ha añadido soporte para WebP en xviewer y thumbnailers.
  • Blueman 2.3 ya está dentro y ha sustituido a Blueberry.
  • En el modo rsync, Timeshinft ahora calcula el espacio necesario para la siguiente captura y la omite si al hacerla dejará menos de 1GB de espacio libre.
  • mintupdate 5.8.3 llegó con algunos cambios que no fueron bien, y más tarde lanzaron mintupdate 5.8.4 sin esa regresión. En Linux Mint 21, mintupdate 5.8.5 ya no depende sólo en los temporizadores/servicios de systemd.

Lo que le ha faltado a la nota de este mes es decir cuándo llegará la beta de Linux Mint 21, que usará el nuevo Cinnamon 5.4. Se han limitado a decir que ya está lista, por lo que deberían lanzar la ISO en los próximos días.

from Linux Adictos https://ift.tt/On5r0Qh
via IFTTT

Software libre para cometer los pecados capitales

Persona disfrazada de diablo

El software libre tiene títulos para todos, incluyendo los pecadores

Como tantos habitantes de América y España, a los nueve años me mandaron a catecismo para tomar la Primera Comunión. Al igual que gran parte de ellos, no volví a pisar una iglesia como no fuera para asistir a un casamiento o bautismo. Por eso, para sacar algún provecho de los conocimientos que insisten en permanecer en mi memoria, va esta lista de software libre para cometer los pecados capitales.

Desde ya que este blog no alienta que se cometan (algunos) pecados Se trata tan solo de una excusa para conocer algunos títulos del enorme catálogo del software libre y de código abierto. Además, imagínate en el Infierno teniendo el castigo de leer mis posts por toda la eternidad.

Qué son los pecados capitales

Los pecados capitales son conductas que según la Iglesia Católica dan origen a todos los demás pecados.
Ellos son:

  • Pereza: Es la negativa para hacer un esfuerzo necesario.
  • Ira: Emoción de odio o enfado no controlado.
  • Soberbia: Tener demasiada buena opinión de uno mismo.
  • Gula: Consumo en demasía de alimentos y bebidas.
  • Lujuria: Uso del placer sexual para la propia gratificación.
  • Avaricia: Deseo de poseer bienes materiales en mayor cantidad de los necesarios para sobrevivir.
  • Envidia: Resentimiento por lo que tienen los demás.

Software libre para cometer los pecados capitales: Pereza

La ayuda más inmediata para los perezosos es los atajos de teclado de la terminal.  Algunos de los más útiles son:

  • CTRL + U: Borrar todos los comandos a la izquierda del cursor.
  • CTRL + L: Borrar todo el contenido de la terminal.
  • CTRL + K: Borrar todo el contenido a la derecha del cursor.
  • CTRL + W: Borrar la palabra a la izquierda del cursor.
  • CTRL + D: Cerrar la sesión actual.
  • CTRL + E: Lleva el cursor al final de la línea.
  • CTRL + Y:  Pegar (Se usa después de CTRL +U, K o W)
  • TAB: Autocompletar archivos o comandos.
  • CTRL + R: Invierte el historial de búsqueda.
  • !!: Repite el último comando tecleado.
  • CTRL + Z: Detiene el comando actual y lo ejecuta en segundo plano.
  • CTRL + C: Detiene la ejecución del comando.

Automatizando tareas

Linux ofrece varias herramientas capaces de evitarnos tener que hacer lo que el ordenador puede hacer por nosotros.

El archivo Crontab

Cron es un demonio que se encarga de realizar, sin intervención del usuario, tareas en un intervalo específico de tiempo. En general, se trata de tareas de mantenimiento que deben realizarse de forma regular. Nada impide, sin embargo, que agreguemos algunas de las que no queremos hacer.

Un archivo crontab es nada más que un archivo de texto que especifica una serie de comandos que deberán ejecutarse en una fecha especificada. Tenemos dos tipos de archivos crontab: el archivo crontab generado por el sistema y, los creados por los usuarios.

De ningún modo deberíamos meternos; en caso de que tengamos privilegios root, con el archivo crontab del sistema ya que es utilizado por Linux para la configuración y mantenimiento del sistema. Este archivo se encuentra en la ruta /etc/crontab.

Creando nuestras propias tareas para cron

Para crear nuestros propios archivos crontab deberemos definir los siguientes parámetros (Los enumero en el orden en que deben escribirse:

m: Representa minutos con un intervalo de 0 a 59.

h: Indica la hora de ejecución con un intervalo de 0 a 23.

d: Determina el día del mes con un intervalo de 1 a 31.

mes: Especifica el mes del año con un intervalo de 1 a 12.

s: Marca el día de la semana en un intervalo de 0 a 6 donde el 0 corresponde al día domingo.

En el caso de que el trabajo cron se cree para el usuario por defecto, se utiliza el comando

crontab –e

Si es para otro usuario debe especificarse el nombre de usuario con el parámetro -u de la forma:

crontab –u nombre de usuario –e

La primera vez que ejecutamos el comando (Desde el emulador de terminal) nos indica que no existe hasta el momento ningún archivo crontab por lo que se va a crear uno vacío. A continuación, nos propone elegir uno de los editores de textos instalados en el sistema para editarlo.

En el próximo artículo continuaremos explicando el uso del comando cron y veremos otras herramientas para trabajar menos.

from Linux Adictos https://ift.tt/3vPJ14R
via IFTTT